# Generated by Django 3.0.7 on 2020-07-01 11:02

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='UserFiles',
            fields=[
                ('username', models.CharField(max_length=64)),
                ('file_path', models.TextField()),
                ('file_dpu', models.CharField(max_length=255, primary_key=True, serialize=False)),
            ],
        ),
        migrations.AddIndex(
            model_name='userfiles',
            index=models.Index(fields=['username'], name='userfiles_username_idx'),
        ),
    ]



import io
import os
import tempfile
import uuid
from unittest.mock import MagicMock
from urllib.parse import urlparse

from airavata.model.data.replica.ttypes import (
    DataProductModel,
    DataProductType,
    DataReplicaLocationModel,
    ReplicaLocationCategory
)
from airavata.model.security.ttypes import AuthzToken
from django.contrib.auth.models import User
from django.test import RequestFactory, TestCase, override_settings

from airavata_django_portal_sdk import user_storage

GATEWAY_ID = 'test-gateway'


@override_settings(GATEWAY_ID=GATEWAY_ID)
class BaseTestCase(TestCase):

    def setUp(self):
        self.user = User.objects.create_user('testuser')
        self.factory = RequestFactory()
        # Dummy POST request
        self.request = self.factory.post('/upload', {})
        self.request.user = self.user
        self.request.airavata_client = MagicMock(name="airavata_client")
        self.product_uri = f"airavata-dp://{uuid.uuid4()}"
        self.request.airavata_client.registerDataProduct.return_value = \
            self.product_uri
        self.request.authz_token = AuthzToken(accessToken="dummy",
                                              claimsMap={'gatewayID': GATEWAY_ID,
                                                         'userName': self.user.username})


class SaveTests(BaseTestCase):

    def test_save_with_defaults(self):
        "Test save with default name and content type"
        with tempfile.TemporaryDirectory() as tmpdirname, \
                self.settings(GATEWAY_DATA_STORE_DIR=tmpdirname,
                              GATEWAY_DATA_STORE_HOSTNAME="gateway.com"):
            # path is just the user directory in gateway storage
            path = os.path.join(tmpdirname, self.user.username)
            file = io.StringIO("Foo file")
            file.name = "foo.txt"
            data_product = user_storage.save(self.request, path, file)

            self.assertEqual(data_product.productUri, self.product_uri)
            self.request.airavata_client.registerDataProduct.\
                assert_called_once()
            args, kws = self.request.airavata_client.registerDataProduct.\
                call_args
            dp = args[1]
            self.assertEqual(self.user.username, dp.ownerName)
            self.assertEqual("foo.txt", dp.productName)
            self.assertEqual(DataProductType.FILE, dp.dataProductType)
            self.assertDictEqual({'mime-type': 'text/plain'},
                                 dp.productMetadata)
            self.assertEqual(1, len(dp.replicaLocations))
            self.assertEqual(f"{path}/{file.name}",
                             dp.replicaLocations[0].filePath)

    def test_save_with_name_and_content_type(self):
        "Test save with specified name and content type"
        # TODO: either change _Datastore to be created anew each time
        #       or create the _Datastore manually with the tmpdirname
        with tempfile.TemporaryDirectory() as tmpdirname, \
                self.settings(GATEWAY_DATA_STORE_DIR=tmpdirname,
                              GATEWAY_DATA_STORE_HOSTNAME="gateway.com"):
            # path is just the user directory in gateway storage
            path = os.path.join(tmpdirname, self.user.username)
            file = io.StringIO("Foo file")
            file.name = "foo.txt"
            data_product = user_storage.save(
                self.request, path, file, name="bar.txt",
                content_type="application/some-app")

            self.assertEqual(data_product.productUri, self.product_uri)
            self.request.airavata_client.registerDataProduct.\
                assert_called_once()
            args, kws = self.request.airavata_client.registerDataProduct.\
                call_args
            dp = args[1]
            self.assertEqual(self.user.username, dp.ownerName)
            self.assertEqual("bar.txt", dp.productName)
            self.assertEqual(DataProductType.FILE, dp.dataProductType)
            self.assertDictEqual({'mime-type': 'application/some-app'},
                                 dp.productMetadata)
            self.assertEqual(1, len(dp.replicaLocations))
            self.assertEqual(f"{path}/bar.txt",
                             dp.replicaLocations[0].filePath)

    def test_save_with_unknown_text_file_type(self):
        "Test save with unknown file ext for text file"
        with tempfile.TemporaryDirectory() as tmpdirname, \
                self.settings(GATEWAY_DATA_STORE_DIR=tmpdirname,
                              GATEWAY_DATA_STORE_HOSTNAME="gateway.com"):
            path = os.path.join(
                tmpdirname, "foo.someext")
            os.makedirs(os.path.dirname(path), exist_ok=True)
            with open(path, 'w') as f:
                f.write("Some Unicode text")
            with open(path, 'r') as f:
                dp = user_storage.save(
                    self.request, "some/path", f,
                    content_type="application/octet-stream")
                # Make sure that the file contents are tested to see if text
                self.assertDictEqual({'mime-type': 'text/plain'},
                                     dp.productMetadata)

    def test_save_with_unknown_binary_file_type(self):
        "Test save with unknown file ext for binary file"
        with tempfile.TemporaryDirectory() as tmpdirname, \
                self.settings(GATEWAY_DATA_STORE_DIR=tmpdirname,
                              GATEWAY_DATA_STORE_HOSTNAME="gateway.com"):
            path = os.path.join(
                tmpdirname, "foo.someext")
            os.makedirs(os.path.dirname(path), exist_ok=True)
            with open(path, 'wb') as f:
                f.write(bytes(range(256)))
            with open(path, 'rb') as f:
                dp = user_storage.save(
                    self.request, "some/path", f,
                    content_type="application/octet-stream")
                # Make sure that DID NOT determine file contents are text
                self.assertDictEqual({'mime-type': 'application/octet-stream'},
                                     dp.productMetadata)


class CopyInputFileUploadTests(BaseTestCase):
    def test_copy_input_file_upload(self):
        "Test copy input file upload copies data product"
        with tempfile.TemporaryDirectory() as tmpdirname, \
                self.settings(GATEWAY_DATA_STORE_DIR=tmpdirname,
                              GATEWAY_DATA_STORE_HOSTNAME="gateway.com"):
            # path is just the user directory in gateway storage
            source_path = os.path.join(
                tmpdirname, self.user.username, "foo.ext")
            os.makedirs(os.path.dirname(source_path))
            with open(source_path, 'wb') as f:
                f.write(b"123")

            data_product = DataProductModel()
            data_product.productUri = f"airavata-dp://{uuid.uuid4()}"
            data_product.gatewayId = GATEWAY_ID
            data_product.ownerName = self.user.username
            data_product.productName = "foo.ext"
            data_product.dataProductType = DataProductType.FILE
            data_product.productMetadata = {
                'mime-type': 'application/some-app'
            }
            replica_category = ReplicaLocationCategory.GATEWAY_DATA_STORE
            replica_path = f"file://gateway.com:{source_path}"
            data_product.replicaLocations = [
                DataReplicaLocationModel(
                    filePath=replica_path,
                    replicaLocationCategory=replica_category)]

            data_product_copy = user_storage.copy_input_file(
                self.request, data_product)

            self.request.airavata_client.registerDataProduct.\
                assert_called_once()
            self.assertIsNot(data_product_copy, data_product)
            self.assertNotEqual(data_product_copy.productUri,
                                data_product.productUri)
            self.assertDictEqual(data_product_copy.productMetadata,
                                 data_product.productMetadata)
            self.assertEqual(data_product_copy.productName,
                             data_product.productName)
            self.assertEqual(data_product_copy.dataProductType,
                             data_product.dataProductType)
            replica_copy_path = data_product_copy.replicaLocations[0].filePath
            self.assertNotEqual(replica_copy_path, replica_path)
            replica_copy_filepath = urlparse(replica_copy_path).path
            self.assertEqual(
                os.path.dirname(replica_copy_filepath),
                os.path.join(tmpdirname, self.user.username, "tmp"),
                msg="Verify input file copied to user's tmp dir")


class ListDirTests(BaseTestCase):
    def test_listdir(self):
        "Verify basic listdir functionality"
        with tempfile.TemporaryDirectory() as tmpdirname, \
                self.settings(GATEWAY_DATA_STORE_DIR=tmpdirname,
                              GATEWAY_DATA_STORE_HOSTNAME="gateway.com"):
            # create test file
            test_file_path = os.path.join(
                tmpdirname, self.user.username, "foo.ext")
            os.makedirs(os.path.dirname(test_file_path))
            with open(test_file_path, 'wb') as f:
                f.write(b"123")
            # create test directory
            os.makedirs(os.path.join(tmpdirname, self.user.username, "testdir"))

            dirs, files = user_storage.listdir(self.request, "")
            self.assertEqual(len(dirs), 1)
            self.assertEqual("testdir", dirs[0]["name"])
            self.assertEqual(len(files), 1)
            self.assertEqual("foo.ext", files[0]["name"])

    def test_listdir_broken_symlink(self):
        "Test that broken symlinks are ignored"
        with tempfile.TemporaryDirectory() as tmpdirname, \
                self.settings(GATEWAY_DATA_STORE_DIR=tmpdirname,
                              GATEWAY_DATA_STORE_HOSTNAME="gateway.com"):
            # create test file
            test_file_path = os.path.join(
                tmpdirname, self.user.username, "foo.ext")
            os.makedirs(os.path.dirname(test_file_path))
            with open(test_file_path, 'wb') as f:
                f.write(b"123")
            # create test directory
            os.makedirs(os.path.join(tmpdirname, self.user.username, "testdir"))
            # create broken symlink
            not_existent = os.path.join("path", "does", "not", "exist")
            self.assertFalse(os.path.exists(not_existent))
            os.symlink(not_existent, os.path.join(tmpdirname, self.user.username, "broken-symlink"))
            self.assertIn("broken-symlink", os.listdir(os.path.join(tmpdirname, self.user.username)))
            # os.path.exists returns False for broken symbolic link
            self.assertFalse(os.path.exists(os.path.join(tmpdirname, self.user.username, "broken-symlink")))

            dirs, files = user_storage.listdir(self.request, "")
            # verify test file and directory are returned, but not broken-symlink
            self.assertEqual(len(dirs), 1)
            self.assertEqual("testdir", dirs[0]["name"])
            self.assertEqual(len(files), 1)
            self.assertEqual("foo.ext", files[0]["name"])
        pass



import warnings
from urllib.parse import urlencode

from django.urls import path, reverse

from . import views


def get_download_url(data_product_uri):
    """(Deprecated) Get URL for downloading data product identified by data_product_uri."""
    warnings.warn("Use user_storage.get_download_url instead.", DeprecationWarning)
    return (reverse("django_airavata_api:download_file") + "?" +
            urlencode({"data-product-uri": data_product_uri}))


app_name = 'airavata_django_portal_sdk'
urlpatterns = [
    path('download-file', views.download_file, name='download_file'),
    path('download', views.download, name='download'),
    path('download-dir', views.download_dir, name='download_dir'),
    path('download-experiment-dir/<experiment_id>', views.download_experiment_dir, name='download_experiment_dir'),
]



import logging
import os
import shutil

from django.core.exceptions import ObjectDoesNotExist, SuspiciousFileOperation
from django.core.files.storage import FileSystemStorage

from .base import UserStorageProvider

logger = logging.getLogger(__name__)


class DjangoFileSystemProvider(UserStorageProvider):
    def __init__(self, authz_token, resource_id, context=None, directory=None, storage_resource_id=None, **kwargs):
        super().__init__(authz_token, resource_id, context=context, **kwargs)
        self.directory = directory
        self.storage_resource_id = resource_id

    def save(self, path, file, name=None, content_type=None):
        full_path = self.datastore.save(path, file, name=name)
        return self.storage_resource_id, full_path

    def open(self, resource_path):
        return self.datastore.open(resource_path)

    def exists(self, resource_path):
        return self.datastore.exists(resource_path)

    def is_file(self, resource_path):
        return self.datastore.file_exists(resource_path)

    def is_dir(self, resource_path):
        return self.datastore.dir_exists(resource_path)

    def get_metadata(self, resource_path):
        # TODO: also return an isDir boolean flag?
        datastore = self.datastore
        if datastore.dir_exists(resource_path):
            directories, files = datastore.list_user_dir(
                resource_path)
            directories_data = []
            for d in directories:
                dpath = os.path.join(resource_path, d)
                created_time = datastore.get_created_time(dpath)
                size = datastore.size(dpath)
                directories_data.append(
                    {
                        "name": d,
                        "path": datastore.rel_path(dpath),
                        "resource_path": datastore.path(dpath),
                        "created_time": created_time,
                        "size": size,
                    }
                )
            files_data = []
            for f in files:
                user_rel_path = os.path.join(resource_path, f)
                if not datastore.exists(user_rel_path):
                    logger.warning(f"listdir skipping {user_rel_path}, "
                                   "does not exist (broken symlink?)")
                    continue
                created_time = datastore.get_created_time(user_rel_path)
                size = datastore.size(user_rel_path)
                full_path = datastore.path(user_rel_path)
                files_data.append(
                    {
                        "name": f,
                        "path": datastore.rel_path(full_path),
                        "resource_path": full_path,
                        "created_time": created_time,
                        "size": size,
                    }
                )
            return directories_data, files_data
        elif datastore.exists(resource_path):

            created_time = datastore.get_created_time(resource_path)
            size = datastore.size(resource_path)
            full_path = datastore.path(resource_path)
            return [], [
                {
                    "name": os.path.basename(resource_path),
                    "path": datastore.rel_path(full_path),
                    "resource_path": full_path,
                    "created_time": created_time,
                    "size": size,
                }
            ]
        else:
            raise ObjectDoesNotExist(f"User storage path does not exist {resource_path}")

    def delete(self, resource_path):
        if self.datastore.file_exists(resource_path):
            self.datastore.delete(resource_path)
        elif self.datastore.dir_exists(resource_path):
            self.datastore.delete_dir(resource_path)
        else:
            raise ObjectDoesNotExist(f"User resource_path does not exist {resource_path}")

    def update(self, resource_path, file):
        full_path = self.datastore.path(resource_path)
        with open(full_path, 'w') as f:
            f.write(file.read())

    def create_dirs(self, resource_path, dir_names=[], create_unique=False):
        datastore = self.datastore
        # Special case: handle creating user's home directory
        if resource_path == '' and not datastore.exists(''):
            datastore.create_user_dir('')
            return self.storage_resource_id, datastore.path(resource_path)
        if not datastore.exists(resource_path):
            raise ObjectDoesNotExist(f"User resource_path does not exist {resource_path}")
        valid_dir_names = []
        for dir_name in dir_names:
            valid_dir_names.append(datastore.get_valid_name(dir_name))
        final_path = os.path.join(resource_path, *valid_dir_names)
        if datastore.exists(final_path) and not create_unique:
            raise Exception(f"Directory {final_path} already exists")
        # Make sure path is unique if it already exists
        final_path = datastore.get_available_name(final_path)
        datastore.create_user_dir(final_path)
        return self.storage_resource_id, datastore.path(final_path)

    def create_symlink(self, source_path, dest_path):
        datastore = self.datastore
        if (datastore.symlink_exists(dest_path) and
                os.path.realpath(source_path) == os.path.realpath(datastore.path(dest_path))):
            logger.debug(f"symlink at {dest_path} already points to {source_path}")
            return
        elif datastore.exists(dest_path):
            raise Exception(f"{dest_path} already exists, but isn't the expected symlink")
        else:
            datastore.create_symlink(source_path, dest_path)

    @property
    def datastore(self):
        directory = os.path.join(self.directory, self.username)
        owner_username = self.context.get('owner_username')
        # When the current user isn't the owner, set the directory based on the owner's username
        if owner_username:
            directory = os.path.join(self.directory, owner_username)
        return _Datastore(directory=directory)


class _Datastore:
    """Internal datastore abstraction."""

    def __init__(self, directory=None):
        self.directory = directory
        self.storage = self._user_data_storage(self.directory)

    def exists(self, path):
        """Check if path exists in this data store."""
        try:
            return self.storage.exists(path)
        except SuspiciousFileOperation as e:
            logger.warning(f"Invalid path: {e}")
            return False

    def file_exists(self, path):
        """Check if file path exists in this data store."""
        try:
            return self.storage.exists(path) and os.path.isfile(self.path(path))
        except SuspiciousFileOperation as e:
            logger.warning(f"Invalid path: {e}")
            return False

    def dir_exists(self, path):
        """Check if directory path exists in this data store."""
        logger.debug(f"dir_exists: {path}, {self.path(path)}")
        try:
            return self.storage.exists(path) and os.path.isdir(self.path(path))
        except SuspiciousFileOperation as e:
            logger.warning(f"Invalid path: {e}")
            return False

    def symlink_exists(self, path):
        """Check if symlink path exists in this data store."""
        logger.debug(f"symlink_exists: {path}, {self.path(path)}")
        try:
            return self.storage.exists(path) and os.path.islink(self.path(path))
        except SuspiciousFileOperation as e:
            logger.warning(f"Invalid path: {e}")
            return False

    def open(self, path):
        """Open path for user if it exists in this data store."""
        if self.exists(path):
            return self.storage.open(path)
        else:
            raise ObjectDoesNotExist(
                "File path does not exist: {}".format(path))

    def save(self, path, file, name=None):
        """Save file to username/path in data store."""
        # file.name may be full path, so get just the name of the file
        file_name = name if name is not None else os.path.basename(file.name)
        user_data_storage = self.storage
        file_path = os.path.join(
            path, user_data_storage.get_valid_name(file_name))
        input_file_name = user_data_storage.save(file_path, file)
        input_file_fullpath = user_data_storage.path(input_file_name)
        return input_file_fullpath

    def create_user_dir(self, path):
        user_data_storage = self.storage
        if not user_data_storage.exists(path):
            self._makedirs(path)
        else:
            raise Exception("Directory {} already exists".format(path))

    def create_symlink(self, source_path, dest_path):
        user_data_storage = self.storage
        full_path = user_data_storage.path(dest_path)
        os.symlink(source_path, full_path)
        return full_path

    def delete(self, path):
        """Delete file in this data store."""
        if self.file_exists(path):
            user_data_storage = self.storage
            user_data_storage.delete(path)
        else:
            raise ObjectDoesNotExist(
                "File path does not exist: {}".format(path))

    def delete_dir(self, path):
        """Delete entire directory in this data store."""
        if self.symlink_exists(path):
            user_path = self.path(path)
            os.unlink(user_path)
        elif self.dir_exists(path):
            user_path = self.path(path)
            shutil.rmtree(user_path)
        else:
            raise ObjectDoesNotExist(
                "File path does not exist: {}".format(path))

    def get_experiment_dir(
        self, project_name=None, experiment_name=None, path=None
    ):
        """Return an experiment directory (full path) for the given experiment."""
        user_experiment_data_storage = self.storage
        if path is None:
            proj_dir_name = user_experiment_data_storage.get_valid_name(
                project_name)
            # AIRAVATA-3245 Make project directory with correct permissions
            if not user_experiment_data_storage.exists(proj_dir_name):
                self._makedirs(proj_dir_name)
            experiment_dir_name = os.path.join(
                proj_dir_name,
                user_experiment_data_storage.get_valid_name(experiment_name),
            )
            # Since there may already be another experiment with the same name in
            # this project, we need to check for available name
            experiment_dir_name = user_experiment_data_storage.get_available_name(
                experiment_dir_name)
            experiment_dir = user_experiment_data_storage.path(
                experiment_dir_name)
        else:
            # path can be relative to the user's storage space or absolute (as long
            # as it is still inside the user's storage space)
            # if path is passed in, assumption is that it has already been
            # created
            user_experiment_data_storage = self.storage
            experiment_dir = user_experiment_data_storage.path(path)
        if not user_experiment_data_storage.exists(experiment_dir):
            self._makedirs(experiment_dir)
        return experiment_dir

    def get_valid_name(self, name):
        return self.storage.get_valid_name(name)

    def get_available_name(self, name):
        return self.storage.get_available_name(name)

    def _makedirs(self, dir_path):
        user_experiment_data_storage = self.storage
        full_path = user_experiment_data_storage.path(dir_path)
        os.makedirs(
            full_path,
            mode=user_experiment_data_storage.directory_permissions_mode)
        # os.makedirs mode isn't always respected so need to chmod to be sure
        os.chmod(
            full_path,
            mode=user_experiment_data_storage.directory_permissions_mode)

    def list_user_dir(self, file_path):
        logger.debug("file_path={}".format(file_path))
        user_data_storage = self.storage
        return user_data_storage.listdir(file_path)

    def get_created_time(self, file_path):
        user_data_storage = self.storage
        return user_data_storage.get_created_time(file_path)

    def size(self, file_path):
        user_data_storage = self.storage
        full_path = self.path(file_path)
        if os.path.isdir(full_path):
            return self._get_dir_size(full_path)
        else:
            return user_data_storage.size(file_path)

    def path(self, file_path):
        user_data_storage = self.storage
        return user_data_storage.path(file_path)

    def rel_path(self, file_path):
        full_path = self.path(file_path)
        return os.path.relpath(full_path, self.path(""))

    def _user_data_storage(self, directory):
        return FileSystemStorage(location=directory)

    # from https://stackoverflow.com/a/1392549
    def _get_dir_size(self, start_path="."):
        total_size = 0
        for dirpath, dirnames, filenames in os.walk(start_path):
            for f in filenames:
                fp = os.path.join(dirpath, f)
                # Check for broken symlinks (.exists return False for broken
                # symlinks)
                if os.path.exists(fp):
                    total_size += os.path.getsize(fp)
        return total_size



import datetime


def convert_iso8601_to_datetime(iso8601string, microseconds=True):
    """Convert ISO8601 datetime string to a datetime instance."""
    if microseconds:
        return datetime.datetime.strptime(iso8601string, "%Y-%m-%dT%H:%M:%S.%fZ")
    else:
        return datetime.datetime.strptime(iso8601string, "%Y-%m-%dT%H:%M:%SZ")



import io
import logging
import os
from datetime import datetime

import grpc
import requests

from . import CredCommon_pb2, MFTApi_pb2, MFTApi_pb2_grpc
from .base import ProvidesDownloadUrl, UserStorageProvider

logger = logging.getLogger(__name__)


class MFTUserStorageProvider(UserStorageProvider, ProvidesDownloadUrl):

    def __init__(self, authz_token, resource_id, context=None, resource_token=None, mft_api_endpoint=None, mft_api_secure=False, resource_per_gateway=False, **kwargs):
        super().__init__(authz_token, resource_id, context=context, **kwargs)
        self.resource_token = resource_token
        self.mft_api_endpoint = mft_api_endpoint
        self.mft_api_secure = mft_api_secure
        self.resource_per_gateway = resource_per_gateway

    def exists(self, resource_path):
        with grpc.insecure_channel(self.mft_api_endpoint) as channel:
            child_path = self._get_child_path(resource_path)
            # TODO: is this still needed?
            # parent_path, child_path = os.path.split(f"/tmp/{resource_path}".rstrip("/"))
            # get metadata for the parent path
            if child_path is not None:
                parent_path, child_path = os.path.split(child_path)
            else:
                parent_path = None
            stub = MFTApi_pb2_grpc.MFTApiServiceStub(channel)
            # Get metadata for parent directory and see if child_path exists
            request = MFTApi_pb2.FetchResourceMetadataRequest(
                # resourceId="remote-ssh-dir-resource",
                resourceId=self.resource_id,
                resourceType="SCP",
                # resourceToken="local-ssh-cred",
                resourceToken=self.resource_token,
                resourceBackend="FILE",
                resourceCredentialBackend="FILE",
                targetAgentId="agent0",
                childPath=parent_path,
                mftAuthorizationToken=self.auth_token,
            )
            try:
                response = stub.getDirectoryResourceMetadata(request)
            except Exception:
                # Could not find the parent path, so apparently doesn't exist
                logger.warning(f"Could not get metadata for {parent_path} on {self.resource_id}")
                return False
            # if not child_path, then return True since the response was
            # successful and we just need to confirm the existence of the root dir
            if child_path is None:
                return True
            return child_path in map(lambda f: f.friendlyName, list(response.directories) + list(response.files))

    def get_metadata(self, resource_path):
        with grpc.insecure_channel(self.mft_api_endpoint) as channel:
            child_path = self._get_child_path(resource_path)
            stub = MFTApi_pb2_grpc.MFTApiServiceStub(channel)
            request = MFTApi_pb2.FetchResourceMetadataRequest(
                # resourceId="remote-ssh-dir-resource",
                resourceId=self.resource_id,
                resourceType="SCP",
                # resourceToken="local-ssh-cred",
                resourceToken=self.resource_token,
                resourceBackend="FILE",
                resourceCredentialBackend="FILE",
                targetAgentId="agent0",
                childPath=child_path,
                mftAuthorizationToken=self.auth_token)
            try:
                logger.debug(f"getDirectoryResourceMetadata({request})")
                response = stub.getDirectoryResourceMetadata(request)
                logger.debug(f"getDirectoryResourceMetadata response={response}")
                directories = response.directories
                files = response.files
            except Exception:
                # if getting metadata for directory fails, try as file
                # FIXME is there a better way to determine if directory or file?
                logger.debug(f"getFileResourceMetadata({request})")
                response = stub.getFileResourceMetadata(request)
                logger.debug(f"getFileResourceMetadata response={response}")
                directories = []
                files = [response]
            directories_data = []
            for d in directories:

                dpath = os.path.join(resource_path, d.friendlyName)
                created_time = datetime.fromtimestamp(d.createdTime)
                # TODO MFT API doesn't report size
                size = 0
                directories_data.append(
                    {
                        "name": d.friendlyName,
                        # path is the relative path, or at least, relative to given resource_path
                        "path": dpath,
                        # resource_path is the id or full path to the resource
                        "resource_path": d.resourcePath,
                        "created_time": created_time,
                        "size": size,
                    }
                )
            files_data = []
            for f in files:
                user_rel_path = os.path.join(resource_path, f.friendlyName)
                # TODO do we need to check for broken symlinks?
                created_time = datetime.fromtimestamp(f.createdTime)
                size = f.resourceSize
                # full_path = datastore.path(request.user.username, user_rel_path)
                # TODO how do we register these as data products, do we need to?
                # data_product_uri = _get_data_product_uri(request, full_path)

                # data_product = request.airavata_client.getDataProduct(
                #     request.authz_token, data_product_uri)
                # mime_type = None
                # if 'mime-type' in data_product.productMetadata:
                #     mime_type = data_product.productMetadata['mime-type']
                files_data.append(
                    {
                        "name": f.friendlyName,
                        "path": user_rel_path,
                        "resource_path": f.resourcePath,
                        "created_time": created_time,
                        "size": size,
                    }
                )
            return directories_data, files_data

    def is_file(self, resource_path):
        with grpc.insecure_channel(self.mft_api_endpoint) as channel:
            child_path = self._get_child_path(resource_path)
            stub = MFTApi_pb2_grpc.MFTApiServiceStub(channel)
            # Get metadata for parent directory and see if child_path exists
            request = MFTApi_pb2.FetchResourceMetadataRequest(
                # resourceId="remote-ssh-dir-resource",
                resourceId=self.resource_id,
                resourceType="SCP",
                # resourceToken="local-ssh-cred",
                resourceToken=self.resource_token,
                resourceBackend="FILE",
                resourceCredentialBackend="FILE",
                targetAgentId="agent0",
                childPath=child_path,
                mftAuthorizationToken=self.auth_token,
            )
            try:
                stub.getFileResourceMetadata(request)
                return True
            except Exception:
                # assume that is doesn't exist, or isn't a file
                logger.warning(f"Could not get metadata for {child_path} on {self.resource_id}")
                return False

    def is_dir(self, resource_path):
        with grpc.insecure_channel(self.mft_api_endpoint) as channel:
            child_path = self._get_child_path(resource_path)
            stub = MFTApi_pb2_grpc.MFTApiServiceStub(channel)
            # Get metadata for parent directory and see if child_path exists
            request = MFTApi_pb2.FetchResourceMetadataRequest(
                # resourceId="remote-ssh-dir-resource",
                resourceId=self.resource_id,
                resourceType="SCP",
                # resourceToken="local-ssh-cred",
                resourceToken=self.resource_token,
                resourceBackend="FILE",
                resourceCredentialBackend="FILE",
                targetAgentId="agent0",
                childPath=child_path,
                mftAuthorizationToken=self.auth_token,
            )
            try:
                stub.getDirectoryResourceMetadata(request)
                return True
            except Exception:
                # assume that it doesn't exist or isn't a file
                logger.warning(f"Could not get metadata for {child_path} on {self.resource_id}")
                return False

    def get_download_url(self, resource_path):
        with grpc.insecure_channel(self.mft_api_endpoint) as channel:
            child_path = self._get_child_path(resource_path)
            stub = MFTApi_pb2_grpc.MFTApiServiceStub(channel)
            download_request = MFTApi_pb2.HttpDownloadApiRequest(
                # sourceResourceId=self.resource_id,
                # FIXME: just hacking in something to force it to work
                sourceResourceId="remote-ssh-resource",
                # sourcePath=child_path,
                sourceToken=self.resource_token,
                sourceType="SCP",
                targetAgent="agent0",
                mftAuthorizationToken=self.auth_token,
            )
            try:
                response = stub.submitHttpDownload(download_request)
                logger.debug(f"Download request for {self.resource_id}:{child_path}. Response = {response}")
                return response.url
            except Exception as e:
                logger.error(f"submitHttpDownload request {download_request} failed.")
                raise Exception(f"Failed to get download url for {resource_path}") from e

    def open(self, resource_path):
        download_url = self.get_download_url(resource_path)
        r = requests.get(download_url)
        r.raise_for_status()
        file = io.BytesIO(r.content)
        file.name = os.path.basename(resource_path)
        return file

    def _get_child_path(self, resource_path):
        """Convert possibly relative child path into absolute path."""
        if not resource_path.startswith("/"):
            # resource_path is relative, need to construct an absolute path
            if self.resource_per_gateway:
                resource_path = os.path.join(self.username, resource_path).rstrip("/")
            # If there is no child path, just return none
            if resource_path == '':
                return None
            logger.debug(f"figuring out resourcePath of {self.resource_id} ...")
            with grpc.insecure_channel(self.mft_api_endpoint) as channel:
                stub = MFTApi_pb2_grpc.MFTApiServiceStub(channel)
                request = MFTApi_pb2.FetchResourceMetadataRequest(
                    # resourceId="remote-ssh-dir-resource",
                    resourceId=self.resource_id,
                    resourceType="SCP",
                    # resourceToken="local-ssh-cred",
                    resourceToken=self.resource_token,
                    resourceBackend="FILE",
                    resourceCredentialBackend="FILE",
                    targetAgentId="agent0",
                    mftAuthorizationToken=self.auth_token)
                response = stub.getDirectoryResourceMetadata(request)
                logger.debug(f"metadata of {self.resource_id} is {response}")
                return os.path.join(response.resourcePath, resource_path)
        else:
            # resource_path appears to be absolute path
            return resource_path

    @property
    def auth_token(self):
        """Instance of CredCommon.AuthToken wrapping user's access token."""
        return CredCommon_pb2.AuthToken(userTokenAuth=CredCommon_pb2.UserTokenAuth(token=self.access_token))



import logging
import os
import tempfile
import zipfile

from django.core.exceptions import ObjectDoesNotExist
from django.http import FileResponse, Http404
from django.shortcuts import redirect
from django.utils.text import get_valid_filename
from django.views.decorators.gzip import gzip_page
from rest_framework.decorators import api_view

from airavata_django_portal_sdk import user_storage

logger = logging.getLogger(__name__)

MAX_DOWNLOAD_ZIPFILE_SIZE = 1 * 1024**3  # 1 GB


@api_view()
def download(request):
    data_product_uri = request.GET.get('data-product-uri', '')
    force_download = 'download' in request.GET
    mime_type = request.GET.get('mime-type')
    download_url = user_storage.get_download_url(request,
                                                 data_product_uri=data_product_uri,
                                                 force_download=force_download,
                                                 mime_type=mime_type)
    return redirect(download_url)


@gzip_page
@api_view()
def download_file(request):
    data_product_uri = request.GET.get('data-product-uri', '')
    force_download = 'download' in request.GET
    data_product = None
    try:
        data_product = request.airavata_client.getDataProduct(
            request.authz_token, data_product_uri)
        mime_type = "application/octet-stream"  # default mime-type
        if (data_product.productMetadata and
                'mime-type' in data_product.productMetadata):
            mime_type = data_product.productMetadata['mime-type']
        # 'mime-type' url parameter overrides
        mime_type = request.GET.get('mime-type', mime_type)
    except Exception as e:
        logger.warning("Failed to load DataProduct for {}"
                       .format(data_product_uri), exc_info=True)
        raise Http404("data product does not exist") from e
    try:
        data_file = user_storage.open_file(request, data_product)
        response = FileResponse(data_file, content_type=mime_type)
        if user_storage.is_input_file(request, data_product):
            file_name = data_product.productName
        else:
            file_name = os.path.basename(data_file.name)
        if mime_type == 'application/octet-stream' or force_download:
            response['Content-Disposition'] = ('attachment; filename="{}"'
                                               .format(file_name))
        else:
            response['Content-Disposition'] = f'inline; filename="{file_name}"'
        return response
    except ObjectDoesNotExist as e:
        raise Http404(str(e)) from e


@api_view()
def download_dir(request):
    path = request.GET.get('path', "")
    fp = tempfile.TemporaryFile()
    with zipfile.ZipFile(fp, 'w', compression=zipfile.ZIP_DEFLATED) as zf:
        _add_directory_to_zipfile(request, zf, path)
    if os.path.basename(path) == "" or get_valid_filename(os.path.basename(path)) == "":
        filename = 'home.zip'
    else:
        filename = get_valid_filename(os.path.basename(path)) + ".zip"
    fp.seek(0)
    # FileResponse will automatically close the temporary file
    return FileResponse(fp, as_attachment=True, filename=filename)


@api_view()
def download_experiment_dir(request, experiment_id=None):
    path = request.GET.get('path', "")
    experiment = request.airavata_client.getExperiment(request.authz_token, experiment_id)
    fp = tempfile.TemporaryFile()
    with zipfile.ZipFile(fp, 'w', compression=zipfile.ZIP_DEFLATED) as zf:
        _add_experiment_directory_to_zipfile(request, zf, experiment_id, path)
    if os.path.basename(path) == "" or get_valid_filename(os.path.basename(path)) == "":
        filename = f'{get_valid_filename(experiment.experimentName)}.zip'
    else:
        filename = f'{get_valid_filename(experiment.experimentName)}_{get_valid_filename(os.path.basename(path))}.zip'
    fp.seek(0)
    # FileResponse will automatically close the temporary file
    return FileResponse(fp, as_attachment=True, filename=filename)


def _add_directory_to_zipfile(request, zf, path, directory=""):
    directories, files = user_storage.listdir(request, os.path.join(path, directory))
    for file in files:
        o = user_storage.open_file(request, data_product_uri=file['data-product-uri'])
        zf.writestr(os.path.join(directory, file['name']), o.read())
        if os.path.getsize(zf.filename) > MAX_DOWNLOAD_ZIPFILE_SIZE:
            raise Exception(f"Zip file size exceeds max of {MAX_DOWNLOAD_ZIPFILE_SIZE} bytes")
    for d in directories:
        _add_directory_to_zipfile(request, zf, path, d['name'])


def _add_experiment_directory_to_zipfile(request, zf, experiment_id, path, directory=""):
    directories, files = user_storage.list_experiment_dir(request, experiment_id, os.path.join(path, directory))
    for file in files:
        o = user_storage.open_file(request, data_product_uri=file['data-product-uri'])
        zf.writestr(os.path.join(directory, file['name']), o.read())
        if os.path.getsize(zf.filename) > MAX_DOWNLOAD_ZIPFILE_SIZE:
            raise Exception(f"Zip file size exceeds max of {MAX_DOWNLOAD_ZIPFILE_SIZE} bytes")
    for d in directories:
        _add_experiment_directory_to_zipfile(request, zf, experiment_id, path, d['name'])



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CredCommon.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='CredCommon.proto',
  package='org.apache.airavata.mft.common',
  syntax='proto3',
  serialized_options=b'P\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10\x43redCommon.proto\x12\x1eorg.apache.airavata.mft.common\"\x1e\n\rUserTokenAuth\x12\r\n\x05token\x18\x01 \x01(\t\"@\n\tAgentAuth\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0f\n\x07\x61gentId\x18\x02 \x01(\t\x12\x13\n\x0b\x61gentSecret\x18\x03 \x01(\t\"\xcb\x01\n\x0c\x44\x65legateAuth\x12\x0e\n\x06userId\x18\x01 \x01(\t\x12\x10\n\x08\x63lientId\x18\x02 \x01(\t\x12\x14\n\x0c\x63lientSecret\x18\x03 \x01(\t\x12P\n\nproperties\x18\x04 \x03(\x0b\x32<.org.apache.airavata.mft.common.DelegateAuth.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xea\x01\n\tAuthToken\x12\x46\n\ruserTokenAuth\x18\x01 \x01(\x0b\x32-.org.apache.airavata.mft.common.UserTokenAuthH\x00\x12>\n\tagentAuth\x18\x02 \x01(\x0b\x32).org.apache.airavata.mft.common.AgentAuthH\x00\x12\x44\n\x0c\x64\x65legateAuth\x18\x03 \x01(\x0b\x32,.org.apache.airavata.mft.common.DelegateAuthH\x00\x42\x0f\n\rauthMechanismB\x02P\x01\x62\x06proto3'
)




_USERTOKENAUTH = _descriptor.Descriptor(
  name='UserTokenAuth',
  full_name='org.apache.airavata.mft.common.UserTokenAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='org.apache.airavata.mft.common.UserTokenAuth.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=82,
)


_AGENTAUTH = _descriptor.Descriptor(
  name='AgentAuth',
  full_name='org.apache.airavata.mft.common.AgentAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='org.apache.airavata.mft.common.AgentAuth.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agentId', full_name='org.apache.airavata.mft.common.AgentAuth.agentId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agentSecret', full_name='org.apache.airavata.mft.common.AgentAuth.agentSecret', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=148,
)


_DELEGATEAUTH_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='org.apache.airavata.mft.common.DelegateAuth.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='org.apache.airavata.mft.common.DelegateAuth.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='org.apache.airavata.mft.common.DelegateAuth.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=354,
)

_DELEGATEAUTH = _descriptor.Descriptor(
  name='DelegateAuth',
  full_name='org.apache.airavata.mft.common.DelegateAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='userId', full_name='org.apache.airavata.mft.common.DelegateAuth.userId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clientId', full_name='org.apache.airavata.mft.common.DelegateAuth.clientId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clientSecret', full_name='org.apache.airavata.mft.common.DelegateAuth.clientSecret', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='org.apache.airavata.mft.common.DelegateAuth.properties', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DELEGATEAUTH_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=354,
)


_AUTHTOKEN = _descriptor.Descriptor(
  name='AuthToken',
  full_name='org.apache.airavata.mft.common.AuthToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='userTokenAuth', full_name='org.apache.airavata.mft.common.AuthToken.userTokenAuth', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agentAuth', full_name='org.apache.airavata.mft.common.AuthToken.agentAuth', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delegateAuth', full_name='org.apache.airavata.mft.common.AuthToken.delegateAuth', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='authMechanism', full_name='org.apache.airavata.mft.common.AuthToken.authMechanism',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=357,
  serialized_end=591,
)

_DELEGATEAUTH_PROPERTIESENTRY.containing_type = _DELEGATEAUTH
_DELEGATEAUTH.fields_by_name['properties'].message_type = _DELEGATEAUTH_PROPERTIESENTRY
_AUTHTOKEN.fields_by_name['userTokenAuth'].message_type = _USERTOKENAUTH
_AUTHTOKEN.fields_by_name['agentAuth'].message_type = _AGENTAUTH
_AUTHTOKEN.fields_by_name['delegateAuth'].message_type = _DELEGATEAUTH
_AUTHTOKEN.oneofs_by_name['authMechanism'].fields.append(
  _AUTHTOKEN.fields_by_name['userTokenAuth'])
_AUTHTOKEN.fields_by_name['userTokenAuth'].containing_oneof = _AUTHTOKEN.oneofs_by_name['authMechanism']
_AUTHTOKEN.oneofs_by_name['authMechanism'].fields.append(
  _AUTHTOKEN.fields_by_name['agentAuth'])
_AUTHTOKEN.fields_by_name['agentAuth'].containing_oneof = _AUTHTOKEN.oneofs_by_name['authMechanism']
_AUTHTOKEN.oneofs_by_name['authMechanism'].fields.append(
  _AUTHTOKEN.fields_by_name['delegateAuth'])
_AUTHTOKEN.fields_by_name['delegateAuth'].containing_oneof = _AUTHTOKEN.oneofs_by_name['authMechanism']
DESCRIPTOR.message_types_by_name['UserTokenAuth'] = _USERTOKENAUTH
DESCRIPTOR.message_types_by_name['AgentAuth'] = _AGENTAUTH
DESCRIPTOR.message_types_by_name['DelegateAuth'] = _DELEGATEAUTH
DESCRIPTOR.message_types_by_name['AuthToken'] = _AUTHTOKEN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserTokenAuth = _reflection.GeneratedProtocolMessageType('UserTokenAuth', (_message.Message,), {
  'DESCRIPTOR' : _USERTOKENAUTH,
  '__module__' : 'CredCommon_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.common.UserTokenAuth)
  })
_sym_db.RegisterMessage(UserTokenAuth)

AgentAuth = _reflection.GeneratedProtocolMessageType('AgentAuth', (_message.Message,), {
  'DESCRIPTOR' : _AGENTAUTH,
  '__module__' : 'CredCommon_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.common.AgentAuth)
  })
_sym_db.RegisterMessage(AgentAuth)

DelegateAuth = _reflection.GeneratedProtocolMessageType('DelegateAuth', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _DELEGATEAUTH_PROPERTIESENTRY,
    '__module__' : 'CredCommon_pb2'
    # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.common.DelegateAuth.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _DELEGATEAUTH,
  '__module__' : 'CredCommon_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.common.DelegateAuth)
  })
_sym_db.RegisterMessage(DelegateAuth)
_sym_db.RegisterMessage(DelegateAuth.PropertiesEntry)

AuthToken = _reflection.GeneratedProtocolMessageType('AuthToken', (_message.Message,), {
  'DESCRIPTOR' : _AUTHTOKEN,
  '__module__' : 'CredCommon_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.common.AuthToken)
  })
_sym_db.RegisterMessage(AuthToken)


DESCRIPTOR._options = None
_DELEGATEAUTH_PROPERTIESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# Generated by Django 2.2.17 on 2021-04-27 11:42

from django.db import migrations, models


def delete_user_file_entries(apps, schema_editor):
    # UserFiles table is just a cache of generated Data Product URIs for files
    # in directory listings.  We can wipe it out safely.  The existing entries
    # need to be deleted because this migration adds a new non-nullable field,
    # file_resource_id, and there's no good default for existing entries.
    UserFiles = apps.get_model('airavata_django_portal_sdk', 'UserFiles')
    UserFiles.objects.all().delete()


class Migration(migrations.Migration):

    dependencies = [
        ('airavata_django_portal_sdk', '0001_initial'),
    ]

    operations = [
        migrations.RunPython(delete_user_file_entries, migrations.RunPython.noop),
        migrations.AddField(
            model_name='userfiles',
            name='file_resource_id',
            field=models.CharField(default='default', max_length=255),
            preserve_default=False,
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MFTApi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import CredCommon_pb2 as CredCommon__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='MFTApi.proto',
  package='org.apache.airavata.mft.api.service',
  syntax='proto3',
  serialized_options=b'P\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0cMFTApi.proto\x12#org.apache.airavata.mft.api.service\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x10\x43redCommon.proto\"\xa3\x03\n\x12TransferApiRequest\x12\x18\n\x10sourceResourceId\x18\x01 \x01(\t\x12\x12\n\nsourceType\x18\x02 \x01(\t\x12\x13\n\x0bsourceToken\x18\x03 \x01(\t\x12\x1d\n\x15\x64\x65stinationResourceId\x18\x07 \x01(\t\x12\x17\n\x0f\x64\x65stinationType\x18\t \x01(\t\x12\x18\n\x10\x64\x65stinationToken\x18\n \x01(\t\x12\x18\n\x10\x61\x66\x66inityTransfer\x18\r \x01(\x08\x12_\n\x0ctargetAgents\x18\x0e \x03(\x0b\x32I.org.apache.airavata.mft.api.service.TransferApiRequest.TargetAgentsEntry\x12H\n\x15mftAuthorizationToken\x18\x0f \x01(\x0b\x32).org.apache.airavata.mft.common.AuthToken\x1a\x33\n\x11TargetAgentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\")\n\x13TransferApiResponse\x12\x12\n\ntransferId\x18\x01 \x01(\t\"\xc7\x01\n\x14HttpUploadApiRequest\x12\x1d\n\x15\x64\x65stinationResourceId\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65stinationToken\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x65stinationType\x18\x04 \x01(\t\x12\x13\n\x0btargetAgent\x18\x05 \x01(\t\x12H\n\x15mftAuthorizationToken\x18\x06 \x01(\x0b\x32).org.apache.airavata.mft.common.AuthToken\"9\n\x15HttpUploadApiResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x13\n\x0btargetAgent\x18\x02 \x01(\t\"\xba\x01\n\x16HttpDownloadApiRequest\x12\x18\n\x10sourceResourceId\x18\x01 \x01(\t\x12\x13\n\x0bsourceToken\x18\x03 \x01(\t\x12\x12\n\nsourceType\x18\x04 \x01(\t\x12\x13\n\x0btargetAgent\x18\x05 \x01(\t\x12H\n\x15mftAuthorizationToken\x18\x06 \x01(\x0b\x32).org.apache.airavata.mft.common.AuthToken\";\n\x17HttpDownloadApiResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x13\n\x0btargetAgent\x18\x02 \x01(\t\"w\n\x17TransferStateApiRequest\x12\x12\n\ntransferId\x18\x01 \x01(\t\x12H\n\x15mftAuthorizationToken\x18\x02 \x01(\x0b\x32).org.apache.airavata.mft.common.AuthToken\"j\n\x18TransferStateApiResponse\x12\r\n\x05state\x18\x01 \x01(\t\x12\x16\n\x0eupdateTimeMils\x18\x02 \x01(\x03\x12\x12\n\npercentage\x18\x03 \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"\xe4\x01\n\x1bResourceAvailabilityRequest\x12\x12\n\nresourceId\x18\x01 \x01(\t\x12\x14\n\x0cresourceType\x18\x02 \x01(\t\x12\x15\n\rresourceToken\x18\x03 \x01(\t\x12\x17\n\x0fresourceBackend\x18\x04 \x01(\t\x12!\n\x19resourceCredentialBackend\x18\x05 \x01(\t\x12H\n\x15mftAuthorizationToken\x18\x06 \x01(\x0b\x32).org.apache.airavata.mft.common.AuthToken\"1\n\x1cResourceAvailabilityResponse\x12\x11\n\tavailable\x18\x01 \x01(\x08\"\xc7\x01\n\x14\x46ileMetadataResponse\x12\x14\n\x0c\x66riendlyName\x18\x01 \x01(\t\x12\x14\n\x0cresourceSize\x18\x02 \x01(\x03\x12\x13\n\x0b\x63reatedTime\x18\x03 \x01(\x03\x12\x12\n\nupdateTime\x18\x04 \x01(\x03\x12\x0e\n\x06md5sum\x18\x05 \x01(\t\x12\x14\n\x0cresourcePath\x18\x06 \x01(\t\x12\x18\n\x10parentResourceId\x18\x07 \x01(\t\x12\x1a\n\x12parentResourceType\x18\x08 \x01(\t\"\xde\x02\n\x19\x44irectoryMetadataResponse\x12\x14\n\x0c\x66riendlyName\x18\x01 \x01(\t\x12\x13\n\x0b\x63reatedTime\x18\x02 \x01(\x03\x12\x12\n\nupdateTime\x18\x03 \x01(\x03\x12\x14\n\x0cresourcePath\x18\x04 \x01(\t\x12\x18\n\x10parentResourceId\x18\x05 \x01(\t\x12\x1a\n\x12parentResourceType\x18\x06 \x01(\t\x12S\n\x0b\x64irectories\x18\x07 \x03(\x0b\x32>.org.apache.airavata.mft.api.service.DirectoryMetadataResponse\x12H\n\x05\x66iles\x18\x08 \x03(\x0b\x32\x39.org.apache.airavata.mft.api.service.FileMetadataResponse\x12\x17\n\x0flazyInitialized\x18\t \x01(\x08\"\x8f\x02\n\x1c\x46\x65tchResourceMetadataRequest\x12\x12\n\nresourceId\x18\x01 \x01(\t\x12\x14\n\x0cresourceType\x18\x02 \x01(\t\x12\x15\n\rresourceToken\x18\x03 \x01(\t\x12\x17\n\x0fresourceBackend\x18\x04 \x01(\t\x12!\n\x19resourceCredentialBackend\x18\x05 \x01(\t\x12\x15\n\rtargetAgentId\x18\x07 \x01(\t\x12\x11\n\tchildPath\x18\x08 \x01(\t\x12H\n\x15mftAuthorizationToken\x18\t \x01(\x0b\x32).org.apache.airavata.mft.common.AuthToken2\xb5\x0b\n\rMFTApiService\x12\x9f\x01\n\x0esubmitTransfer\x12\x37.org.apache.airavata.mft.api.service.TransferApiRequest\x1a\x38.org.apache.airavata.mft.api.service.TransferApiResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x12/v1.0/api/transfer\x12\xa8\x01\n\x10submitHttpUpload\x12\x39.org.apache.airavata.mft.api.service.HttpUploadApiRequest\x1a:.org.apache.airavata.mft.api.service.HttpUploadApiResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x15/v1.0/api/http-upload\x12\xb0\x01\n\x12submitHttpDownload\x12;.org.apache.airavata.mft.api.service.HttpDownloadApiRequest\x1a<.org.apache.airavata.mft.api.service.HttpDownloadApiResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/v1.0/api/http-download\x12\xb5\x01\n\x11getTransferStates\x12<.org.apache.airavata.mft.api.service.TransferStateApiRequest\x1a=.org.apache.airavata.mft.api.service.TransferStateApiResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1.0/api/transfer/states0\x01\x12\xb1\x01\n\x10getTransferState\x12<.org.apache.airavata.mft.api.service.TransferStateApiRequest\x1a=.org.apache.airavata.mft.api.service.TransferStateApiResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1.0/api/transfer/state\x12\xa0\x01\n\x17getResourceAvailability\x12@.org.apache.airavata.mft.api.service.ResourceAvailabilityRequest\x1a\x41.org.apache.airavata.mft.api.service.ResourceAvailabilityResponse\"\x00\x12\xc1\x01\n\x17getFileResourceMetadata\x12\x41.org.apache.airavata.mft.api.service.FetchResourceMetadataRequest\x1a\x39.org.apache.airavata.mft.api.service.FileMetadataResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1.0/api/resource/metadata/file\x12\xd0\x01\n\x1cgetDirectoryResourceMetadata\x12\x41.org.apache.airavata.mft.api.service.FetchResourceMetadataRequest\x1a>.org.apache.airavata.mft.api.service.DirectoryMetadataResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/v1.0/api/resource/metadata/directoryB\x02P\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,CredCommon__pb2.DESCRIPTOR,])




_TRANSFERAPIREQUEST_TARGETAGENTSENTRY = _descriptor.Descriptor(
  name='TargetAgentsEntry',
  full_name='org.apache.airavata.mft.api.service.TransferApiRequest.TargetAgentsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='org.apache.airavata.mft.api.service.TransferApiRequest.TargetAgentsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='org.apache.airavata.mft.api.service.TransferApiRequest.TargetAgentsEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=550,
)

_TRANSFERAPIREQUEST = _descriptor.Descriptor(
  name='TransferApiRequest',
  full_name='org.apache.airavata.mft.api.service.TransferApiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sourceResourceId', full_name='org.apache.airavata.mft.api.service.TransferApiRequest.sourceResourceId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sourceType', full_name='org.apache.airavata.mft.api.service.TransferApiRequest.sourceType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sourceToken', full_name='org.apache.airavata.mft.api.service.TransferApiRequest.sourceToken', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destinationResourceId', full_name='org.apache.airavata.mft.api.service.TransferApiRequest.destinationResourceId', index=3,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destinationType', full_name='org.apache.airavata.mft.api.service.TransferApiRequest.destinationType', index=4,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destinationToken', full_name='org.apache.airavata.mft.api.service.TransferApiRequest.destinationToken', index=5,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='affinityTransfer', full_name='org.apache.airavata.mft.api.service.TransferApiRequest.affinityTransfer', index=6,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetAgents', full_name='org.apache.airavata.mft.api.service.TransferApiRequest.targetAgents', index=7,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mftAuthorizationToken', full_name='org.apache.airavata.mft.api.service.TransferApiRequest.mftAuthorizationToken', index=8,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRANSFERAPIREQUEST_TARGETAGENTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=550,
)


_TRANSFERAPIRESPONSE = _descriptor.Descriptor(
  name='TransferApiResponse',
  full_name='org.apache.airavata.mft.api.service.TransferApiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transferId', full_name='org.apache.airavata.mft.api.service.TransferApiResponse.transferId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=552,
  serialized_end=593,
)


_HTTPUPLOADAPIREQUEST = _descriptor.Descriptor(
  name='HttpUploadApiRequest',
  full_name='org.apache.airavata.mft.api.service.HttpUploadApiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='destinationResourceId', full_name='org.apache.airavata.mft.api.service.HttpUploadApiRequest.destinationResourceId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destinationToken', full_name='org.apache.airavata.mft.api.service.HttpUploadApiRequest.destinationToken', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destinationType', full_name='org.apache.airavata.mft.api.service.HttpUploadApiRequest.destinationType', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetAgent', full_name='org.apache.airavata.mft.api.service.HttpUploadApiRequest.targetAgent', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mftAuthorizationToken', full_name='org.apache.airavata.mft.api.service.HttpUploadApiRequest.mftAuthorizationToken', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=596,
  serialized_end=795,
)


_HTTPUPLOADAPIRESPONSE = _descriptor.Descriptor(
  name='HttpUploadApiResponse',
  full_name='org.apache.airavata.mft.api.service.HttpUploadApiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='org.apache.airavata.mft.api.service.HttpUploadApiResponse.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetAgent', full_name='org.apache.airavata.mft.api.service.HttpUploadApiResponse.targetAgent', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=797,
  serialized_end=854,
)


_HTTPDOWNLOADAPIREQUEST = _descriptor.Descriptor(
  name='HttpDownloadApiRequest',
  full_name='org.apache.airavata.mft.api.service.HttpDownloadApiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sourceResourceId', full_name='org.apache.airavata.mft.api.service.HttpDownloadApiRequest.sourceResourceId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sourceToken', full_name='org.apache.airavata.mft.api.service.HttpDownloadApiRequest.sourceToken', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sourceType', full_name='org.apache.airavata.mft.api.service.HttpDownloadApiRequest.sourceType', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetAgent', full_name='org.apache.airavata.mft.api.service.HttpDownloadApiRequest.targetAgent', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mftAuthorizationToken', full_name='org.apache.airavata.mft.api.service.HttpDownloadApiRequest.mftAuthorizationToken', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=857,
  serialized_end=1043,
)


_HTTPDOWNLOADAPIRESPONSE = _descriptor.Descriptor(
  name='HttpDownloadApiResponse',
  full_name='org.apache.airavata.mft.api.service.HttpDownloadApiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='org.apache.airavata.mft.api.service.HttpDownloadApiResponse.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetAgent', full_name='org.apache.airavata.mft.api.service.HttpDownloadApiResponse.targetAgent', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1045,
  serialized_end=1104,
)


_TRANSFERSTATEAPIREQUEST = _descriptor.Descriptor(
  name='TransferStateApiRequest',
  full_name='org.apache.airavata.mft.api.service.TransferStateApiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transferId', full_name='org.apache.airavata.mft.api.service.TransferStateApiRequest.transferId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mftAuthorizationToken', full_name='org.apache.airavata.mft.api.service.TransferStateApiRequest.mftAuthorizationToken', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1106,
  serialized_end=1225,
)


_TRANSFERSTATEAPIRESPONSE = _descriptor.Descriptor(
  name='TransferStateApiResponse',
  full_name='org.apache.airavata.mft.api.service.TransferStateApiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='org.apache.airavata.mft.api.service.TransferStateApiResponse.state', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateTimeMils', full_name='org.apache.airavata.mft.api.service.TransferStateApiResponse.updateTimeMils', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='org.apache.airavata.mft.api.service.TransferStateApiResponse.percentage', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='org.apache.airavata.mft.api.service.TransferStateApiResponse.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1227,
  serialized_end=1333,
)


_RESOURCEAVAILABILITYREQUEST = _descriptor.Descriptor(
  name='ResourceAvailabilityRequest',
  full_name='org.apache.airavata.mft.api.service.ResourceAvailabilityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resourceId', full_name='org.apache.airavata.mft.api.service.ResourceAvailabilityRequest.resourceId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceType', full_name='org.apache.airavata.mft.api.service.ResourceAvailabilityRequest.resourceType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceToken', full_name='org.apache.airavata.mft.api.service.ResourceAvailabilityRequest.resourceToken', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceBackend', full_name='org.apache.airavata.mft.api.service.ResourceAvailabilityRequest.resourceBackend', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceCredentialBackend', full_name='org.apache.airavata.mft.api.service.ResourceAvailabilityRequest.resourceCredentialBackend', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mftAuthorizationToken', full_name='org.apache.airavata.mft.api.service.ResourceAvailabilityRequest.mftAuthorizationToken', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1336,
  serialized_end=1564,
)


_RESOURCEAVAILABILITYRESPONSE = _descriptor.Descriptor(
  name='ResourceAvailabilityResponse',
  full_name='org.apache.airavata.mft.api.service.ResourceAvailabilityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='available', full_name='org.apache.airavata.mft.api.service.ResourceAvailabilityResponse.available', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1566,
  serialized_end=1615,
)


_FILEMETADATARESPONSE = _descriptor.Descriptor(
  name='FileMetadataResponse',
  full_name='org.apache.airavata.mft.api.service.FileMetadataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='friendlyName', full_name='org.apache.airavata.mft.api.service.FileMetadataResponse.friendlyName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceSize', full_name='org.apache.airavata.mft.api.service.FileMetadataResponse.resourceSize', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createdTime', full_name='org.apache.airavata.mft.api.service.FileMetadataResponse.createdTime', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateTime', full_name='org.apache.airavata.mft.api.service.FileMetadataResponse.updateTime', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='md5sum', full_name='org.apache.airavata.mft.api.service.FileMetadataResponse.md5sum', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourcePath', full_name='org.apache.airavata.mft.api.service.FileMetadataResponse.resourcePath', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parentResourceId', full_name='org.apache.airavata.mft.api.service.FileMetadataResponse.parentResourceId', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parentResourceType', full_name='org.apache.airavata.mft.api.service.FileMetadataResponse.parentResourceType', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1618,
  serialized_end=1817,
)


_DIRECTORYMETADATARESPONSE = _descriptor.Descriptor(
  name='DirectoryMetadataResponse',
  full_name='org.apache.airavata.mft.api.service.DirectoryMetadataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='friendlyName', full_name='org.apache.airavata.mft.api.service.DirectoryMetadataResponse.friendlyName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createdTime', full_name='org.apache.airavata.mft.api.service.DirectoryMetadataResponse.createdTime', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateTime', full_name='org.apache.airavata.mft.api.service.DirectoryMetadataResponse.updateTime', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourcePath', full_name='org.apache.airavata.mft.api.service.DirectoryMetadataResponse.resourcePath', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parentResourceId', full_name='org.apache.airavata.mft.api.service.DirectoryMetadataResponse.parentResourceId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parentResourceType', full_name='org.apache.airavata.mft.api.service.DirectoryMetadataResponse.parentResourceType', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='directories', full_name='org.apache.airavata.mft.api.service.DirectoryMetadataResponse.directories', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='files', full_name='org.apache.airavata.mft.api.service.DirectoryMetadataResponse.files', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lazyInitialized', full_name='org.apache.airavata.mft.api.service.DirectoryMetadataResponse.lazyInitialized', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1820,
  serialized_end=2170,
)


_FETCHRESOURCEMETADATAREQUEST = _descriptor.Descriptor(
  name='FetchResourceMetadataRequest',
  full_name='org.apache.airavata.mft.api.service.FetchResourceMetadataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resourceId', full_name='org.apache.airavata.mft.api.service.FetchResourceMetadataRequest.resourceId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceType', full_name='org.apache.airavata.mft.api.service.FetchResourceMetadataRequest.resourceType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceToken', full_name='org.apache.airavata.mft.api.service.FetchResourceMetadataRequest.resourceToken', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceBackend', full_name='org.apache.airavata.mft.api.service.FetchResourceMetadataRequest.resourceBackend', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceCredentialBackend', full_name='org.apache.airavata.mft.api.service.FetchResourceMetadataRequest.resourceCredentialBackend', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetAgentId', full_name='org.apache.airavata.mft.api.service.FetchResourceMetadataRequest.targetAgentId', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='childPath', full_name='org.apache.airavata.mft.api.service.FetchResourceMetadataRequest.childPath', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mftAuthorizationToken', full_name='org.apache.airavata.mft.api.service.FetchResourceMetadataRequest.mftAuthorizationToken', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2173,
  serialized_end=2444,
)

_TRANSFERAPIREQUEST_TARGETAGENTSENTRY.containing_type = _TRANSFERAPIREQUEST
_TRANSFERAPIREQUEST.fields_by_name['targetAgents'].message_type = _TRANSFERAPIREQUEST_TARGETAGENTSENTRY
_TRANSFERAPIREQUEST.fields_by_name['mftAuthorizationToken'].message_type = CredCommon__pb2._AUTHTOKEN
_HTTPUPLOADAPIREQUEST.fields_by_name['mftAuthorizationToken'].message_type = CredCommon__pb2._AUTHTOKEN
_HTTPDOWNLOADAPIREQUEST.fields_by_name['mftAuthorizationToken'].message_type = CredCommon__pb2._AUTHTOKEN
_TRANSFERSTATEAPIREQUEST.fields_by_name['mftAuthorizationToken'].message_type = CredCommon__pb2._AUTHTOKEN
_RESOURCEAVAILABILITYREQUEST.fields_by_name['mftAuthorizationToken'].message_type = CredCommon__pb2._AUTHTOKEN
_DIRECTORYMETADATARESPONSE.fields_by_name['directories'].message_type = _DIRECTORYMETADATARESPONSE
_DIRECTORYMETADATARESPONSE.fields_by_name['files'].message_type = _FILEMETADATARESPONSE
_FETCHRESOURCEMETADATAREQUEST.fields_by_name['mftAuthorizationToken'].message_type = CredCommon__pb2._AUTHTOKEN
DESCRIPTOR.message_types_by_name['TransferApiRequest'] = _TRANSFERAPIREQUEST
DESCRIPTOR.message_types_by_name['TransferApiResponse'] = _TRANSFERAPIRESPONSE
DESCRIPTOR.message_types_by_name['HttpUploadApiRequest'] = _HTTPUPLOADAPIREQUEST
DESCRIPTOR.message_types_by_name['HttpUploadApiResponse'] = _HTTPUPLOADAPIRESPONSE
DESCRIPTOR.message_types_by_name['HttpDownloadApiRequest'] = _HTTPDOWNLOADAPIREQUEST
DESCRIPTOR.message_types_by_name['HttpDownloadApiResponse'] = _HTTPDOWNLOADAPIRESPONSE
DESCRIPTOR.message_types_by_name['TransferStateApiRequest'] = _TRANSFERSTATEAPIREQUEST
DESCRIPTOR.message_types_by_name['TransferStateApiResponse'] = _TRANSFERSTATEAPIRESPONSE
DESCRIPTOR.message_types_by_name['ResourceAvailabilityRequest'] = _RESOURCEAVAILABILITYREQUEST
DESCRIPTOR.message_types_by_name['ResourceAvailabilityResponse'] = _RESOURCEAVAILABILITYRESPONSE
DESCRIPTOR.message_types_by_name['FileMetadataResponse'] = _FILEMETADATARESPONSE
DESCRIPTOR.message_types_by_name['DirectoryMetadataResponse'] = _DIRECTORYMETADATARESPONSE
DESCRIPTOR.message_types_by_name['FetchResourceMetadataRequest'] = _FETCHRESOURCEMETADATAREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TransferApiRequest = _reflection.GeneratedProtocolMessageType('TransferApiRequest', (_message.Message,), {

  'TargetAgentsEntry' : _reflection.GeneratedProtocolMessageType('TargetAgentsEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFERAPIREQUEST_TARGETAGENTSENTRY,
    '__module__' : 'MFTApi_pb2'
    # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.api.service.TransferApiRequest.TargetAgentsEntry)
    })
  ,
  'DESCRIPTOR' : _TRANSFERAPIREQUEST,
  '__module__' : 'MFTApi_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.api.service.TransferApiRequest)
  })
_sym_db.RegisterMessage(TransferApiRequest)
_sym_db.RegisterMessage(TransferApiRequest.TargetAgentsEntry)

TransferApiResponse = _reflection.GeneratedProtocolMessageType('TransferApiResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERAPIRESPONSE,
  '__module__' : 'MFTApi_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.api.service.TransferApiResponse)
  })
_sym_db.RegisterMessage(TransferApiResponse)

HttpUploadApiRequest = _reflection.GeneratedProtocolMessageType('HttpUploadApiRequest', (_message.Message,), {
  'DESCRIPTOR' : _HTTPUPLOADAPIREQUEST,
  '__module__' : 'MFTApi_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.api.service.HttpUploadApiRequest)
  })
_sym_db.RegisterMessage(HttpUploadApiRequest)

HttpUploadApiResponse = _reflection.GeneratedProtocolMessageType('HttpUploadApiResponse', (_message.Message,), {
  'DESCRIPTOR' : _HTTPUPLOADAPIRESPONSE,
  '__module__' : 'MFTApi_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.api.service.HttpUploadApiResponse)
  })
_sym_db.RegisterMessage(HttpUploadApiResponse)

HttpDownloadApiRequest = _reflection.GeneratedProtocolMessageType('HttpDownloadApiRequest', (_message.Message,), {
  'DESCRIPTOR' : _HTTPDOWNLOADAPIREQUEST,
  '__module__' : 'MFTApi_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.api.service.HttpDownloadApiRequest)
  })
_sym_db.RegisterMessage(HttpDownloadApiRequest)

HttpDownloadApiResponse = _reflection.GeneratedProtocolMessageType('HttpDownloadApiResponse', (_message.Message,), {
  'DESCRIPTOR' : _HTTPDOWNLOADAPIRESPONSE,
  '__module__' : 'MFTApi_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.api.service.HttpDownloadApiResponse)
  })
_sym_db.RegisterMessage(HttpDownloadApiResponse)

TransferStateApiRequest = _reflection.GeneratedProtocolMessageType('TransferStateApiRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERSTATEAPIREQUEST,
  '__module__' : 'MFTApi_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.api.service.TransferStateApiRequest)
  })
_sym_db.RegisterMessage(TransferStateApiRequest)

TransferStateApiResponse = _reflection.GeneratedProtocolMessageType('TransferStateApiResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERSTATEAPIRESPONSE,
  '__module__' : 'MFTApi_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.api.service.TransferStateApiResponse)
  })
_sym_db.RegisterMessage(TransferStateApiResponse)

ResourceAvailabilityRequest = _reflection.GeneratedProtocolMessageType('ResourceAvailabilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEAVAILABILITYREQUEST,
  '__module__' : 'MFTApi_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.api.service.ResourceAvailabilityRequest)
  })
_sym_db.RegisterMessage(ResourceAvailabilityRequest)

ResourceAvailabilityResponse = _reflection.GeneratedProtocolMessageType('ResourceAvailabilityResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEAVAILABILITYRESPONSE,
  '__module__' : 'MFTApi_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.api.service.ResourceAvailabilityResponse)
  })
_sym_db.RegisterMessage(ResourceAvailabilityResponse)

FileMetadataResponse = _reflection.GeneratedProtocolMessageType('FileMetadataResponse', (_message.Message,), {
  'DESCRIPTOR' : _FILEMETADATARESPONSE,
  '__module__' : 'MFTApi_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.api.service.FileMetadataResponse)
  })
_sym_db.RegisterMessage(FileMetadataResponse)

DirectoryMetadataResponse = _reflection.GeneratedProtocolMessageType('DirectoryMetadataResponse', (_message.Message,), {
  'DESCRIPTOR' : _DIRECTORYMETADATARESPONSE,
  '__module__' : 'MFTApi_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.api.service.DirectoryMetadataResponse)
  })
_sym_db.RegisterMessage(DirectoryMetadataResponse)

FetchResourceMetadataRequest = _reflection.GeneratedProtocolMessageType('FetchResourceMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _FETCHRESOURCEMETADATAREQUEST,
  '__module__' : 'MFTApi_pb2'
  # @@protoc_insertion_point(class_scope:org.apache.airavata.mft.api.service.FetchResourceMetadataRequest)
  })
_sym_db.RegisterMessage(FetchResourceMetadataRequest)


DESCRIPTOR._options = None
_TRANSFERAPIREQUEST_TARGETAGENTSENTRY._options = None

_MFTAPISERVICE = _descriptor.ServiceDescriptor(
  name='MFTApiService',
  full_name='org.apache.airavata.mft.api.service.MFTApiService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2447,
  serialized_end=3908,
  methods=[
  _descriptor.MethodDescriptor(
    name='submitTransfer',
    full_name='org.apache.airavata.mft.api.service.MFTApiService.submitTransfer',
    index=0,
    containing_service=None,
    input_type=_TRANSFERAPIREQUEST,
    output_type=_TRANSFERAPIRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\"\022/v1.0/api/transfer',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='submitHttpUpload',
    full_name='org.apache.airavata.mft.api.service.MFTApiService.submitHttpUpload',
    index=1,
    containing_service=None,
    input_type=_HTTPUPLOADAPIREQUEST,
    output_type=_HTTPUPLOADAPIRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\"\025/v1.0/api/http-upload',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='submitHttpDownload',
    full_name='org.apache.airavata.mft.api.service.MFTApiService.submitHttpDownload',
    index=2,
    containing_service=None,
    input_type=_HTTPDOWNLOADAPIREQUEST,
    output_type=_HTTPDOWNLOADAPIRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\"\027/v1.0/api/http-download',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getTransferStates',
    full_name='org.apache.airavata.mft.api.service.MFTApiService.getTransferStates',
    index=3,
    containing_service=None,
    input_type=_TRANSFERSTATEAPIREQUEST,
    output_type=_TRANSFERSTATEAPIRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/v1.0/api/transfer/states',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getTransferState',
    full_name='org.apache.airavata.mft.api.service.MFTApiService.getTransferState',
    index=4,
    containing_service=None,
    input_type=_TRANSFERSTATEAPIREQUEST,
    output_type=_TRANSFERSTATEAPIRESPONSE,
    serialized_options=b'\202\323\344\223\002\032\022\030/v1.0/api/transfer/state',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getResourceAvailability',
    full_name='org.apache.airavata.mft.api.service.MFTApiService.getResourceAvailability',
    index=5,
    containing_service=None,
    input_type=_RESOURCEAVAILABILITYREQUEST,
    output_type=_RESOURCEAVAILABILITYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getFileResourceMetadata',
    full_name='org.apache.airavata.mft.api.service.MFTApiService.getFileResourceMetadata',
    index=6,
    containing_service=None,
    input_type=_FETCHRESOURCEMETADATAREQUEST,
    output_type=_FILEMETADATARESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /v1.0/api/resource/metadata/file',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getDirectoryResourceMetadata',
    full_name='org.apache.airavata.mft.api.service.MFTApiService.getDirectoryResourceMetadata',
    index=7,
    containing_service=None,
    input_type=_FETCHRESOURCEMETADATAREQUEST,
    output_type=_DIRECTORYMETADATARESPONSE,
    serialized_options=b'\202\323\344\223\002\'\022%/v1.0/api/resource/metadata/directory',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MFTAPISERVICE)

DESCRIPTOR.services_by_name['MFTApiService'] = _MFTAPISERVICE

# @@protoc_insertion_point(module_scope)
